@@ -9,7 +9,7 @@ from functools import wraps
 from pathlib import Path
 
 from . import configutils
-from .backend import Backend
+from .backend import Backend, findTemplates
 
 def common_opts(*F):
   def composed(a):
@@ -82,7 +82,7 @@ def installDefaults(symlink):
 @ensureB
 def install(src_directory, name, symlink):
   """
-  Install a new template
+  Install a new template.
   """
   src_directory = Path(src_directory)
   if name is None :
@@ -101,32 +101,46 @@ def uninstall(name):
   click.echo(f'{name} uninstalled at {f}')
 
 @main.command(name='list')
+@click.argument('paths', nargs=-1)
 @ensureB
-def listTemplates():
+def listTemplates(paths):
   """
-  List installed templates
+  List installed templates. If paths are given, search from them instead of the installed ones.
   """
-  default, user = B.listTemplates()
   se = click.secho
-  se('\n')
-  se('User-installed templates :', fg='cyan', nl=False)
-  se('\n  ', nl=False)
-  se("\n  ".join(user), fg='green', nl=False)
-  se('\n\n', nl=False)
-  se('Default templates :', fg='cyan', nl=False)
-  se('\n  ', nl=False)
-  se("\n  ".join(default), fg='green', nl=False)
-  se('\n')
+  if len(paths) == 0 :
+    default, user = B.listTemplates()
+    se('\n')
+    se('User-installed templates :', fg='cyan', nl=False)
+    se('\n  ', nl=False)
+    se("\n  ".join(map(str, user)), fg='green', nl=False)
+    se('\n\n', nl=False)
+    se('Default templates :', fg='cyan', nl=False)
+    se('\n  ', nl=False)
+    se("\n  ".join(map(str, default)), fg='green', nl=False)
+    se('\n')
+
+  else:
+    for p in map(Path, paths) :
+      templates = findTemplates(p, p)
+      se('\n')
+      se(f'Templates found in {p} :', fg='cyan', nl=False)
+      se('\n  ', nl=False)
+      se("\n  ".join(map(str, templates)), fg='green', nl=False)
+      se('\n\n', nl=False)
+      
 
 
 @main.command(name='gen')
 @click.option('--debug', '-g', is_flag=True)
 @click.argument('template', type=click.Path())
 @click.argument('dest', type=str)
+@click.option('--stdout', is_flag=True, help='Only for single file templates : output to stdout. --single-file is implied')
+@click.option('--single-file', '-s', is_flag=True, help='Authorize single file template for non installed templates.')
 @click.argument('args', nargs=-1, type=click.UNPROCESSED)
 @click.pass_context
 @ensureB
-def gen(ctx, debug, template, dest, args):
+def gen(ctx, debug, template, dest, stdout, single_file, args):
   """
   Generate a skeleton from a template.
 
@@ -138,8 +152,12 @@ def gen(ctx, debug, template, dest, args):
     from . import pluginutils
     pluginutils.__ctx = ctx
     pluginutils.__name = f'{template} {dest} --'
-    template_path = B.findTemplate(template)
-    res, help = B.execTemplate(template_path, dest, args)
+    template_path = B.findTemplate(template, single_file_authorized=single_file or stdout)
+    out_f = None
+    if stdout :
+      import sys
+      out_f = sys.stdout
+    res, help = B.execTemplate(template_path, dest, args, out_f)
     if not res :
       click.echo(help)
   except:
